@@ -626,9 +626,9 @@ class GutenbergDublinCore(DublinCore):
 
 
     def load_from_pgheader(self, data):
-        """ Load DublinCore from Project Gutenberg ebook.
+        """ Load DublinCore from Project Gutenberg ebook file.
 
-        Worst method. Use as last resort only.
+        When a parser is supplied, data from the parser is used
 
         """
 
@@ -795,6 +795,11 @@ class GutenbergDublinCore(DublinCore):
                     continue
 
                 if re.search('START OF', line):
+                    # debug("Dispatching: %s => %s" % (last_prefix, buf.strip()))
+                    
+                    if last_prefix:
+                        dispatcher[last_prefix](self, last_prefix, buf.strip())
+                    
                     break
 
                 prefix, sep, suffix = line.partition(':')
@@ -873,7 +878,8 @@ class GutenbergDublinCore(DublinCore):
             'character set encoding': 'encoding',
             'copyright':              'rights',
             'alternate title':        'alt_title',
-            'created':                'source_publication_years'
+            'created':                'source_publication_years',
+            'produced by':            'credit',
             }
 
         for role in list(self.inverse_role_map.keys()):
